@@ -217,7 +217,7 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
                             sorted(value.items()))
 
         if parameter == "version":
-            self.version = ".".join(value.split(".")[:3])
+            value = self.version = ".".join(value.split(".")[:3])
 
         return value
 
@@ -229,35 +229,45 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         data = get_data(response)
         return dict((k.lower(), v) for k, v in data.items())
 
-    def enable_api(self):
-        """Enable LoadMaster API"""
-        # Can't use the HttpClient methods for this as the
-        # endpoint is different when attempting to enable the API.
-        try:
+    def enable_api(self, health_check_api=False):
+        """ Enable LoadMaster RESTfull API
+
+        This method will attempt to enable the LoadMaster's REST API the 'right' way
+        by initially trying to set it with enableapi parameter. If this fails it will
+        attempt to set it the old way using the progs URL.
+
+        :param health_check_api: If True, an extra call to the API will be made
+                                 to verify operability, only works for machines older
+                                 than 7.2.36.
+        :return: True if successfully enabled.
+        """
+        # Can't use the HttpClient methods for this as the endpoint is different
+        # (or has strict stipulations) when attempting to enable the API.
+        def do_request(cmd):
+            url = "https://{}:{}/{}".format(self.ip_address, self.port, cmd)
             if self.cert:
-                url = ("https://{ip}:{port}/progs/doconfig/enableapi/set/yes".
-                       format(ip=self.ip_address, port=self.port))
-                resp = self._tls_session.get(url, verify=False, timeout=1,
-                                             cert=self.cert)
-                url = ("https://{ip}:{port}/progs/status/logout".
-                       format(ip=self.ip_address, port=self.port))
-                self._tls_session.get(url, verify=False, timeout=1,
-                                      cert=self.cert)
+                resp = self._tls_session.get(url, verify=False, timeout=1, cert=self.cert)
             else:
-                url = ("https://{user}:{pw}@{ip}:{port}/progs/doconfig/"
-                       "enableapi/set/yes").format(user=self.username,
-                                                   pw=self.password,
-                                                   ip=self.ip_address,
-                                                   port=self.port)
-                resp = self._tls_session.get(url, verify=False, timeout=1)
-                url = ("https://{user}:{pw}@{ip}:{port}"
-                       "/progs/status/logout").format(user=self.username,
-                                                      pw=self.password,
-                                                      ip=self.ip_address,
-                                                      port=self.port)
-                resp = self._tls_session.get(url, verify=False, timeout=1)
-            self._tls_session.close()
-            resp.raise_for_status()
+                resp = self._tls_session.get(url, verify=False, timeout=1,
+                                             auth=(self.username, self.password))
+                self._tls_session.close()
+            return resp.status_code
+
+        try:
+            status_code = do_request('access/set?param=enableapi&value=yes')
+            if status_code == 404:
+                do_request('progs/doconfig/enableapi/set/yes')
+                status_code = do_request('progs/status/logout')
+                if status_code != 200:
+                    raise KempTechApiException(code=status_code)
+                if health_check_api:
+                    # Health check to see if API was actually enabled
+                    # if it failed its usually due to auth error so raise a 401
+                    status_code = do_request('access/get?param=motd')
+                    if status_code != 200:
+                        raise KempTechApiException(code=401)
+            elif status_code != 200:
+                raise KempTechApiException(code=status_code)
             return True
         except exceptions.RequestException as e:
             raise KempTechApiException("Enable API failed because of: {}".format(
