@@ -19,7 +19,14 @@ from netaddr import IPAddress, AddrFormatError
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.poolmanager import PoolManager
 
-from .exceptions import ValidationError
+from python_kemptech_api.exceptions import (
+    KempTechApiException,
+    ValidationError)
+from python_kemptech_api.api_xml import (
+    is_successful,
+    parse_to_dict,
+    get_error_msg)
+
 
 IS_PY3 = sys.version[0] == '3'
 TIMEOUT = 5
@@ -29,6 +36,10 @@ def validate_port(port):
     try:
         p = int(port)
     except ValueError:
+        if port == "*":
+            # * is allowed for creating wildcard VSs
+            return
+
         raise ValidationError('Port must be an integer ({} given)'
                               .format(port))
 
@@ -82,16 +93,22 @@ def get_sub_vs_list_from_data(response_data):
     return subvs_entries, full_data
 
 
+def send_response(response):
+    if is_successful(response):
+        return parse_to_dict(response)
+    else:
+        raise KempTechApiException(get_error_msg(response))
+
+
 def get_api_bool_string(api_bool):
+    """Return KEMP restfull API version of a bool string"""
     return 'y' if api_bool else 'n'
 
 
 def get_dict_entry_as_list(key, data):
     """Returns an entry from a dict as a list"""
     value = data.get(key, [])
-    if not isinstance(value, list):
-        value = [value]
-    return value
+    return cast_to_list(value)
 
 
 def cast_to_list(data):
@@ -116,3 +133,34 @@ def falsey_to_none(var):
     if not var:
         var = None
     return var
+
+
+def build_object(class_to_build, access_info, data_for_instance):
+    """Factory method that can can build instances of BaseKempObject
+
+    :param class_to_build: Subclass of BaseKempObject
+    :param access_info: Access info that will allow it to attach to parent
+    :param data_for_instance: Default data for class instance
+    :return: Instance of class populated with access info and default data
+    """
+    build_parameters = {}
+
+    for parameter, tag in class_to_build.API_INIT_PARAMS.items():
+        build_parameters[parameter] = data_for_instance.get(tag)
+
+    obj = class_to_build(access_info, **build_parameters)
+    obj.populate_default_attributes(data_for_instance)
+    return obj
+
+
+def list_object(class_to_list, access_info, data):
+    xml_object = data.get(class_to_list.API_TAG, [])
+    xml_object = cast_to_list(xml_object)
+
+    obj_list = []
+
+    for x in xml_object:
+        obj = build_object(class_to_list, access_info, x)
+        obj_list.append(obj)
+
+    return obj_list
