@@ -3,8 +3,7 @@ from unittest import skip
 from nose.tools import (
     assert_equal, assert_raises, assert_true,
     assert_is_none, assert_not_in, assert_greater, assert_less,
-    assert_greater_equal, assert_less_equal, assert_not_equal, assert_false,
-    assert_in)
+    assert_greater_equal, assert_less_equal, assert_not_equal, assert_false)
 
 import requests
 from requests import Session
@@ -400,15 +399,34 @@ class TestLmApiWrapperCalls:
         assert_false(lm1 <= lm2)
         assert_false(lm1 >= lm2)
 
-    def test_enable_api(self):
-        actual = self.lm.enable_api()
-        assert_true(actual)
+    def test_new_enable_api_url(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        self.get.return_value = resp
+        assert_true(self.lm.enable_api())
 
-        self.lm.cert = "not None"
-        actual = self.lm.enable_api()
-        assert_true(actual)
+    def test_new_enable_api_url_wrong_credentials(self):
+        resp = mock.Mock()
+        resp.status_code = 401
+        self.get.return_value = resp
+        with assert_raises(exceptions.KempTechApiException):
+            self.lm.enable_api()
+
+    def test_old_enable_api_url(self):
+        resp = mock.MagicMock()
+        #resp.status_code = mock.
+        #resp.status_code = mock.PropertyMock(side_effect=[401, 200, 200])
+        #resp.status_code.side_effect = [401, 200, 200]
+        self.get.return_value = resp
+        self.lm.enable_api(True)
+
+    def test_old_enable_api_url_wrong_credentials(self):
+        pass
+        #self.lm.enable_api(True)
 
     def test_enable_api_exception(self):
-        self.get.side_effect = requests.exceptions.HTTPError
-        with assert_raises(exceptions.KempTechApiException) as e:
-            self.lm.enable_api()
+        with patch.object(LoadMaster, "get_parameter") as get_parameter:
+            get_parameter.return_value = "7.1.30"
+            self.get.side_effect = requests.exceptions.HTTPError
+            with assert_raises(exceptions.KempTechApiException) as e:
+                self.lm.enable_api()
